@@ -1,4 +1,8 @@
+require('../../node_modules/@elastic/charts/dist/index.js');
 require('../../node_modules/@elastic/datemath/target/index.js');
+require('../../node_modules/@elastic/ems-client/target/web/index.js');
+require('../../node_modules/@elastic/eui/dist/eui_charts_theme.js');
+require('../../node_modules/@elastic/eui/dist/eui_theme_dark.json');
 require('../../node_modules/@elastic/eui/dist/eui_theme_light.json');
 require('../../node_modules/@elastic/eui/lib/index.js');
 require('../../node_modules/@elastic/eui/lib/services/index.js');
@@ -28,6 +32,7 @@ require('../../node_modules/brace/mode/hjson.js');
 require('../../node_modules/brace/mode/json.js');
 require('../../node_modules/brace/mode/less.js');
 require('../../node_modules/brace/mode/markdown.js');
+require('../../node_modules/brace/mode/text.js');
 require('../../node_modules/brace/theme/github.js');
 require('../../node_modules/brace/theme/textmate.js');
 require('../../node_modules/buffer/index.js');
@@ -243,6 +248,7 @@ require('../../node_modules/d3/d3.js');
 require('../../node_modules/encode-uri-query/index.js');
 require('../../node_modules/events/events.js');
 require('../../node_modules/handlebars/dist/handlebars.js');
+require('../../node_modules/history/index.js');
 require('../../node_modules/hjson/lib/hjson.js');
 require('../../node_modules/inline-style/index.js');
 require('../../node_modules/json-stringify-pretty-compact/index.js');
@@ -250,11 +256,9 @@ require('../../node_modules/leaflet-vega/dist/bundle.js');
 require('../../node_modules/less/lib/less-browser/index.js');
 require('../../node_modules/lodash/index.js');
 require('../../node_modules/lodash/internal/toPath.js');
-require('../../node_modules/lru-cache/index.js');
 require('../../node_modules/markdown-it/index.js');
 require('../../node_modules/mustache/mustache.js');
 require('../../node_modules/ngreact/ngReact.js');
-require('../../node_modules/node-fetch/index.js');
 require('../../node_modules/path-browserify/index.js');
 require('../../node_modules/pegjs/lib/peg.js');
 require('../../node_modules/prop-types/index.js');
@@ -269,10 +273,12 @@ require('../../node_modules/react-color/lib/helpers/color.js');
 require('../../node_modules/react-dom/index.js');
 require('../../node_modules/react-grid-layout/index.js');
 require('../../node_modules/react-markdown/lib/react-markdown.js');
+require('../../node_modules/react-redux/lib/index.js');
 require('../../node_modules/react-router-dom/index.js');
 require('../../node_modules/react-sizeme/commonjs/index.js');
 require('../../node_modules/react/index.js');
 require('../../node_modules/reactcss/lib/index.js');
+require('../../node_modules/redux/lib/redux.js');
 require('../../node_modules/regenerator-runtime/runtime.js');
 require('../../node_modules/reselect/lib/index.js');
 require('../../node_modules/resize-observer-polyfill/dist/ResizeObserver.js');
@@ -308,6 +314,7 @@ require('../../webpackShims/childnode-remove-polyfill.js');
 require('../../webpackShims/elasticsearch-browser.js');
 require('../../webpackShims/jquery.js');
 require('../../webpackShims/leaflet.js');
+require('../../webpackShims/lru-cache.js');
 require('../../webpackShims/moment-timezone.js');
 require('../../webpackShims/moment.js');
 require('../../webpackShims/numeral.js');
\ No newline at end of file
