@@ -26,6 +26,7 @@ import {
 import { RangeFilterManager } from './filter_manager/range_filter_manager';
 import { createSearchSource } from './create_search_source';
 import { i18n } from '@kbn/i18n';
+import { start as data } from '../../../../core_plugins/data/public/legacy';
 
 const minMaxAgg = (field) => {
   const aggBody = {};
@@ -55,7 +56,6 @@ class RangeControl extends Control {
       this.abortController.abort();
     }
     this.abortController = new AbortController();
-
     const indexPattern = this.filterManager.getIndexPattern();
     if (!indexPattern) {
       this.disable(noIndexPatternMsg(this.controlParams.indexPattern));
@@ -64,7 +64,7 @@ class RangeControl extends Control {
 
     const fieldName = this.filterManager.fieldName;
 
-    const aggs = minMaxAgg(indexPattern.fields.byName[fieldName]);
+    const aggs = minMaxAgg(indexPattern.fields.getByName(fieldName));
     const searchSource = createSearchSource(this.kbnApi, null, indexPattern, aggs, this.useTimeFilter);
     this.abortController.signal.addEventListener('abort', () => searchSource.cancelQueued());
 
@@ -74,7 +74,6 @@ class RangeControl extends Control {
     } catch(error) {
       // If the fetch was aborted then no need to surface this error in the UI
       if (error.name === 'AbortError') return;
-
       this.disable(i18n.translate('inputControl.rangeControl.unableToFetchTooltip', {
         defaultMessage: 'Unable to fetch range min and max, error: {errorMessage}',
         values: { errorMessage: error.message }
@@ -103,13 +102,13 @@ class RangeControl extends Control {
 export async function rangeControlFactory(controlParams, kbnApi, useTimeFilter) {
   let indexPattern;
   try {
-    indexPattern = await kbnApi.indexPatterns.get(controlParams.indexPattern);
+    indexPattern = await data.indexPatterns.indexPatterns.get(controlParams.indexPattern);
   } catch (err) {
     // ignore not found error and return control so it can be displayed in disabled state.
   }
   return new RangeControl(
     controlParams,
-    new RangeFilterManager(controlParams.id, controlParams.fieldName, indexPattern, kbnApi.queryFilter),
+    new RangeFilterManager(controlParams.id, controlParams.fieldName, indexPattern, data.filter.filterManager),
     kbnApi,
     useTimeFilter
   );
