@@ -23,6 +23,7 @@ import { I18nContext } from 'ui/i18n';
 import { InputControlVis } from './components/vis/input_control_vis';
 import { controlFactory } from './control/control_factory';
 import { getLineageMap } from './lineage';
+import { start as data } from '../../../core_plugins/data/public/legacy';
 
 class VisController {
   constructor(el, vis) {
@@ -32,7 +33,8 @@ class VisController {
 
     this.queryBarUpdateHandler = this.updateControlsFromKbn.bind(this);
 
-    this.updateSubsciption = this.vis.API.queryFilter.getUpdates$()
+    this.filterManager = data.filter.filterManager;
+    this.updateSubsciption = this.filterManager.getUpdates$()
       .subscribe(this.queryBarUpdateHandler);
   }
 
@@ -117,15 +119,6 @@ class VisController {
   }
 
   submitFilters = () => {
-    // Clean up filter pills for nested controls that are now disabled because ancestors are not set
-    this.controls.map(async (control) => {
-      if (control.hasAncestors() && control.hasUnsetAncestor()) {
-        control.filterManager.findFilters().forEach((existingFilter) => {
-          this.vis.API.queryFilter.removeFilter(existingFilter);
-        });
-      }
-    });
-
     const stagedControls = this.controls.filter((control) => {
       return control.hasChanged();
     });
@@ -141,11 +134,22 @@ class VisController {
     stagedControls.forEach((control) => {
       // to avoid duplicate filters, remove any old filters for control
       control.filterManager.findFilters().forEach((existingFilter) => {
-        this.vis.API.queryFilter.removeFilter(existingFilter);
+        this.filterManager.removeFilter(existingFilter);
       });
     });
 
-    this.vis.API.queryFilter.addFilters(newFilters, this.visParams.pinFilters);
+    // Clean up filter pills for nested controls that are now disabled because ancestors are not set.
+    // This has to be done after looking up the staged controls because otherwise removing a filter
+    // will re-sync the controls of all other filters.
+    this.controls.map((control) => {
+      if (control.hasAncestors() && control.hasUnsetAncestor()) {
+        control.filterManager.findFilters().forEach((existingFilter) => {
+          this.filterManager.removeFilter(existingFilter);
+        });
+      }
+    });
+
+    this.filterManager.addFilters(newFilters, this.visParams.pinFilters);
   }
 
   clearControls = async () => {
