@@ -17,22 +17,25 @@
  * under the License.
  */
 
-import { VisFactoryProvider } from 'ui/vis/vis_factory';
 import { i18n } from '@kbn/i18n';
 import { Schemas } from 'ui/vis/editors/default/schemas';
-import { colorSchemas } from 'ui/vislib/components/color/colormaps';
+import { AggGroupNames } from 'ui/vis/editors/default';
+import { ColorSchemas } from 'ui/vislib/components/color/colormaps';
 import { GaugeOptions } from './components/options';
+import { getGaugeCollections, GaugeTypes, ColorModes } from './utils/collections';
+import { vislibVisController } from './controller';
+import { visFactory } from '../../../ui/public/vis/vis_factory';
 
-export default function GoalVisType(Private) {
-  const VisFactory = Private(VisFactoryProvider);
+export default function GoalVisType() {
 
-  return VisFactory.createVislibVisualization({
+  return visFactory.createBaseVisualization({
     name: 'goal',
     title: i18n.translate('kbnVislibVisTypes.goal.goalTitle', { defaultMessage: 'Goal' }),
     icon: 'visGoal',
     description: i18n.translate('kbnVislibVisTypes.goal.goalDescription', {
       defaultMessage: 'A goal chart indicates how close you are to your final goal.'
     }),
+    visualization: vislibVisController,
     visConfig: {
       defaults: {
         addTooltip: true,
@@ -43,13 +46,13 @@ export default function GoalVisType(Private) {
           verticalSplit: false,
           autoExtend: false,
           percentageMode: true,
-          gaugeType: 'Arc',
+          gaugeType: GaugeTypes.ARC,
           gaugeStyle: 'Full',
           backStyle: 'Full',
           orientation: 'vertical',
           useRanges: false,
-          colorSchema: 'Green to Red',
-          gaugeColorMode: 'None',
+          colorSchema: ColorSchemas.GreenToRed,
+          gaugeColorMode: ColorModes.NONE,
           colorsRange: [
             { from: 0, to: 10000 }
           ],
@@ -75,44 +78,12 @@ export default function GoalVisType(Private) {
         }
       },
     },
-    events: {
-      brush: { disabled: true },
-    },
     editorConfig: {
-      collections: {
-        gaugeTypes: [
-          {
-            text: i18n.translate('kbnVislibVisTypes.gauge.gaugeTypes.arcText', {
-              defaultMessage: 'Arc',
-            }),
-            value: 'Arc',
-          },
-          {
-            text: i18n.translate('kbnVislibVisTypes.gauge.gaugeTypes.circleText', {
-              defaultMessage: 'Circle',
-            }),
-            value: 'Circle',
-          },
-        ],
-        alignments: [
-          {
-            value: 'automatic',
-            text: i18n.translate('kbnVislibVisTypes.gauge.alignmentAutomaticTitle', { defaultMessage: 'Automatic' })
-          },
-          {
-            value: 'horizontal',
-            text: i18n.translate('kbnVislibVisTypes.gauge.alignmentHorizontalTitle', { defaultMessage: 'Horizontal' })
-          },
-          {
-            value: 'vertical',
-            text: i18n.translate('kbnVislibVisTypes.gauge.alignmentVerticalTitle', { defaultMessage: 'Vertical' }) },
-        ],
-        colorSchemas,
-      },
+      collections: getGaugeCollections(),
       optionsTemplate: GaugeOptions,
       schemas: new Schemas([
         {
-          group: 'metrics',
+          group: AggGroupNames.Metrics,
           name: 'metric',
           title: i18n.translate('kbnVislibVisTypes.goal.metricTitle', { defaultMessage: 'Metric' }),
           min: 1,
@@ -124,7 +95,7 @@ export default function GoalVisType(Private) {
           ]
         },
         {
-          group: 'buckets',
+          group: AggGroupNames.Buckets,
           name: 'group',
           title: i18n.translate('kbnVislibVisTypes.goal.groupTitle', { defaultMessage: 'Split group' }),
           min: 0,
