@@ -17,23 +17,35 @@
  * under the License.
  */
 
-import { VisFactoryProvider } from 'ui/vis/vis_factory';
+import { visFactory } from '../../../ui/public/vis/vis_factory';
 import { i18n } from '@kbn/i18n';
 import { Schemas } from 'ui/vis/editors/default/schemas';
-import { PointSeriesOptions } from './components/options';
-import { getLegendPositions, LegendPositions } from './utils/legend_positions';
+import { AggGroupNames } from 'ui/vis/editors/default';
+import {
+  Positions,
+  ChartTypes,
+  ChartModes,
+  AxisTypes,
+  ScaleTypes,
+  AxisModes,
+  Rotates,
+  ThresholdLineStyles,
+  getConfigCollections,
+} from './utils/collections';
+import { getAreaOptionTabs, countLabel } from './utils/common_config';
 import { palettes } from '@elastic/eui/lib/services';
+import { vislibVisController } from './controller';
 
-export default function PointSeriesVisType(Private) {
-  const VisFactory = Private(VisFactoryProvider);
+export default function PointSeriesVisType() {
 
-  return VisFactory.createVislibVisualization({
+  return visFactory.createBaseVisualization({
     name: 'histogram',
     title: i18n.translate('kbnVislibVisTypes.histogram.histogramTitle', { defaultMessage: 'Vertical Bar' }),
     icon: 'visBarVertical',
     description: i18n.translate('kbnVislibVisTypes.histogram.histogramDescription',
       { defaultMessage: 'Assign a continuous variable to each axis' }
     ),
+    visualization: vislibVisController,
     visConfig: {
       defaults: {
         type: 'histogram',
@@ -43,12 +55,12 @@ export default function PointSeriesVisType(Private) {
         categoryAxes: [
           {
             id: 'CategoryAxis-1',
-            type: 'category',
-            position: 'bottom',
+            type: AxisTypes.CATEGORY,
+            position: Positions.BOTTOM,
             show: true,
             style: {},
             scale: {
-              type: 'linear'
+              type: ScaleTypes.LINEAR,
             },
             labels: {
               show: true,
@@ -62,42 +74,43 @@ export default function PointSeriesVisType(Private) {
           {
             id: 'ValueAxis-1',
             name: 'LeftAxis-1',
-            type: 'value',
-            position: 'left',
+            type: AxisTypes.VALUE,
+            position: Positions.LEFT,
             show: true,
             style: {},
             scale: {
-              type: 'linear',
-              mode: 'normal'
+              type: ScaleTypes.LINEAR,
+              mode: AxisModes.NORMAL,
             },
             labels: {
               show: true,
-              rotate: 0,
+              rotate: Rotates.HORIZONTAL,
               filter: false,
               truncate: 100
             },
             title: {
-              text: 'Count'
+              text: countLabel,
             }
           }
         ],
         seriesParams: [
           {
-            show: 'true',
-            type: 'histogram',
-            mode: 'stacked',
+            show: true,
+            type: ChartTypes.HISTOGRAM,
+            mode: ChartModes.STACKED,
             data: {
-              label: 'Count',
+              label: countLabel,
               id: '1'
             },
             valueAxis: 'ValueAxis-1',
             drawLinesBetweenPoints: true,
+            lineWidth: 2,
             showCircles: true
           }
         ],
         addTooltip: true,
         addLegend: true,
-        legendPosition: LegendPositions.RIGHT,
+        legendPosition: Positions.RIGHT,
         times: [],
         addTimeMarker: false,
         labels: {
@@ -107,51 +120,20 @@ export default function PointSeriesVisType(Private) {
           show: false,
           value: 10,
           width: 1,
-          style: 'full',
+          style: ThresholdLineStyles.FULL,
           color: palettes.euiPaletteColorBlind.colors[9]
         }
       },
     },
+    events: {
+      brush: { disabled: false },
+    },
     editorConfig: {
-      collections: {
-        legendPositions: getLegendPositions(),
-        positions: ['top', 'left', 'right', 'bottom'],
-        chartTypes: [{
-          value: 'line',
-          text: 'line'
-        }, {
-          value: 'area',
-          text: 'area'
-        }, {
-          value: 'histogram',
-          text: 'bar'
-        }],
-        axisModes: ['normal', 'percentage', 'wiggle', 'silhouette'],
-        scaleTypes: ['linear', 'log', 'square root'],
-        chartModes: ['normal', 'stacked'],
-        interpolationModes: [{
-          value: 'linear',
-          text: 'straight',
-        }, {
-          value: 'cardinal',
-          text: 'smoothed',
-        }, {
-          value: 'step-after',
-          text: 'stepped',
-        }],
-      },
-      optionTabs: [
-        {
-          name: 'advanced',
-          title: 'Metrics & Axes',
-          editor: '<div><vislib-series></vislib-series><vislib-value-axes>' +
-          '</vislib-value-axes><vislib-category-axis></vislib-category-axis></div>'
-        },
-        { name: 'options', title: 'Panel Settings', editor: PointSeriesOptions },
-      ],
+      collections: getConfigCollections(),
+      optionTabs: getAreaOptionTabs(),
       schemas: new Schemas([
         {
-          group: 'metrics',
+          group: AggGroupNames.Metrics,
           name: 'metric',
           title: i18n.translate('kbnVislibVisTypes.histogram.metricTitle', { defaultMessage: 'Y-axis' }),
           min: 1,
@@ -161,7 +143,7 @@ export default function PointSeriesVisType(Private) {
           ]
         },
         {
-          group: 'metrics',
+          group: AggGroupNames.Metrics,
           name: 'radius',
           title: i18n.translate('kbnVislibVisTypes.histogram.radiusTitle', { defaultMessage: 'Dot size' }),
           min: 0,
@@ -169,7 +151,7 @@ export default function PointSeriesVisType(Private) {
           aggFilter: ['count', 'avg', 'sum', 'min', 'max', 'cardinality']
         },
         {
-          group: 'buckets',
+          group: AggGroupNames.Buckets,
           name: 'segment',
           title: i18n.translate('kbnVislibVisTypes.histogram.segmentTitle', { defaultMessage: 'X-axis' }),
           min: 0,
@@ -177,7 +159,7 @@ export default function PointSeriesVisType(Private) {
           aggFilter: ['!geohash_grid', '!geotile_grid', '!filter']
         },
         {
-          group: 'buckets',
+          group: AggGroupNames.Buckets,
           name: 'group',
           title: i18n.translate('kbnVislibVisTypes.histogram.groupTitle', { defaultMessage: 'Split series' }),
           min: 0,
@@ -185,7 +167,7 @@ export default function PointSeriesVisType(Private) {
           aggFilter: ['!geohash_grid', '!geotile_grid', '!filter']
         },
         {
-          group: 'buckets',
+          group: AggGroupNames.Buckets,
           name: 'split',
           title: i18n.translate('kbnVislibVisTypes.histogram.splitTitle', { defaultMessage: 'Split chart' }),
           min: 0,
