@@ -28,7 +28,6 @@ export function fetchAnchorProvider(indexPatterns, Private) {
 
   return async function fetchAnchor(
     indexPatternId,
-    anchorType,
     anchorId,
     sort
   ) {
@@ -43,7 +42,6 @@ export function fetchAnchorProvider(indexPatterns, Private) {
           constant_score: {
             filter: {
               ids: {
-                type: anchorType,
                 values: [anchorId],
               },
             },
