@@ -40,12 +40,6 @@ export function QueryParameterActionsProvider(indexPatterns, Private) {
     )
   );
 
-  const increasePredecessorCount = (state) => (
-    value = state.queryParameters.defaultStepSize,
-  ) => (
-    setPredecessorCount(state)(state.queryParameters.predecessorCount + value)
-  );
-
   const setSuccessorCount = (state) => (successorCount) => (
     state.queryParameters.successorCount = clamp(
       MIN_CONTEXT_SIZE,
@@ -54,12 +48,6 @@ export function QueryParameterActionsProvider(indexPatterns, Private) {
     )
   );
 
-  const increaseSuccessorCount = (state) => (
-    value = state.queryParameters.defaultStepSize,
-  ) => (
-    setSuccessorCount(state)(state.queryParameters.successorCount + value)
-  );
-
   const setQueryParameters = (state) => (queryParameters) => (
     Object.assign(
       state.queryParameters,
@@ -82,8 +70,6 @@ export function QueryParameterActionsProvider(indexPatterns, Private) {
   return {
     addFilter,
     updateFilters,
-    increasePredecessorCount,
-    increaseSuccessorCount,
     setPredecessorCount,
     setQueryParameters,
     setSuccessorCount,
