@@ -19,14 +19,10 @@
 
 import React, { Fragment } from 'react';
 import PropTypes from 'prop-types';
-import { injectI18n, FormattedMessage } from '@kbn/i18n/react';
+import { FormattedMessage } from '@kbn/i18n/react';
 import { i18n } from '@kbn/i18n';
 
-import {
-  EuiLink,
-  EuiButton,
-  EuiEmptyPrompt,
-} from '@elastic/eui';
+import { EuiLink, EuiButton, EuiEmptyPrompt } from '@elastic/eui';
 
 import { TableListView } from './../../table_list_view';
 
@@ -37,8 +33,7 @@ export const EMPTY_FILTER = '';
 // and not supporting server-side paging.
 // This component does not try to tackle these problems (yet) and is just feature matching the legacy component
 // TODO support server side sorting/paging once title and description are sortable on the server.
-class DashboardListingUi extends React.Component {
-
+export class DashboardListing extends React.Component {
   constructor(props) {
     super(props);
   }
@@ -54,21 +49,15 @@ class DashboardListingUi extends React.Component {
         listingLimit={this.props.listingLimit}
         initialFilter={this.props.initialFilter}
         noItemsFragment={this.getNoItemsMessage()}
-        entityName={
-          i18n.translate('kbn.dashboard.listing.table.entityName', {
-            defaultMessage: 'dashboard'
-          })
-        }
-        entityNamePlural={
-          i18n.translate('kbn.dashboard.listing.table.entityNamePlural', {
-            defaultMessage: 'dashboards'
-          })
-        }
-        tableListTitle={
-          i18n.translate('kbn.dashboard.listing.dashboardsTitle', {
-            defaultMessage: 'Dashboards'
-          })
-        }
+        entityName={i18n.translate('kbn.dashboard.listing.table.entityName', {
+          defaultMessage: 'dashboard',
+        })}
+        entityNamePlural={i18n.translate('kbn.dashboard.listing.table.entityNamePlural', {
+          defaultMessage: 'dashboards',
+        })}
+        tableListTitle={i18n.translate('kbn.dashboard.listing.dashboardsTitle', {
+          defaultMessage: 'Dashboards',
+        })}
       />
     );
   }
@@ -146,7 +135,6 @@ class DashboardListingUi extends React.Component {
         />
       </div>
     );
-
   }
 
   getTableColumns() {
@@ -154,7 +142,7 @@ class DashboardListingUi extends React.Component {
       {
         field: 'title',
         name: i18n.translate('kbn.dashboard.listing.table.titleColumnName', {
-          defaultMessage: 'Title'
+          defaultMessage: 'Title',
         }),
         sortable: true,
         render: (field, record) => (
@@ -164,22 +152,22 @@ class DashboardListingUi extends React.Component {
           >
             {field}
           </EuiLink>
-        )
+        ),
       },
       {
         field: 'description',
         name: i18n.translate('kbn.dashboard.listing.table.descriptionColumnName', {
-          defaultMessage: 'Description'
+          defaultMessage: 'Description',
         }),
         dataType: 'string',
         sortable: true,
-      }
+      },
     ];
     return tableColumns;
   }
 }
 
-DashboardListingUi.propTypes = {
+DashboardListing.propTypes = {
   createItem: PropTypes.func.isRequired,
   findItems: PropTypes.func.isRequired,
   deleteItems: PropTypes.func.isRequired,
@@ -190,8 +178,6 @@ DashboardListingUi.propTypes = {
   initialFilter: PropTypes.string,
 };
 
-DashboardListingUi.defaultProps = {
+DashboardListing.defaultProps = {
   initialFilter: EMPTY_FILTER,
 };
-
-export const DashboardListing = injectI18n(DashboardListingUi);
