@@ -19,12 +19,12 @@
 
 import { uiModules } from 'ui/modules';
 import { DevToolsRegistryProvider } from 'ui/registry/dev_tools';
-import { getNewPlatform } from 'ui/new_platform';
+import { npStart } from 'ui/new_platform';
 
 export function hideEmptyDevTools(Private) {
   const hasTools = !!Private(DevToolsRegistryProvider).length;
   if (!hasTools) {
-    getNewPlatform().start.core.chrome.navLinks.update('kibana:dev_tools', {
+    npStart.core.chrome.navLinks.update('kibana:dev_tools', {
       hidden: true
     });
   }
