@@ -29,6 +29,7 @@ import dateMath from '@elastic/datemath';
 // doc table
 import '../doc_table';
 import { getSort } from '../doc_table/lib/get_sort';
+import { getSortForSearchSource } from '../doc_table/lib/get_sort_for_search_source';
 import * as columnActions from '../doc_table/actions/columns';
 import * as filterActions from '../doc_table/actions/filter';
 
@@ -53,9 +54,7 @@ import { StateProvider } from 'ui/state_management/state';
 import { migrateLegacyQuery } from 'ui/utils/migrate_legacy_query';
 import { subscribeWithScope } from 'ui/utils/subscribe_with_scope';
 import { getFilterGenerator } from 'ui/filter_manager';
-import { SavedObjectsClientProvider } from 'ui/saved_objects';
-import { VisualizeLoaderProvider } from 'ui/visualize/loader/visualize_loader';
-import { recentlyAccessed } from 'ui/persisted_log';
+
 import { getDocLink } from 'ui/documentation_links';
 import '../components/fetch_error';
 import { getPainlessError } from './get_painless_error';
@@ -72,7 +71,9 @@ import { getRootBreadcrumbs, getSavedSearchBreadcrumbs } from '../breadcrumbs';
 import { buildVislibDimensions } from 'ui/visualize/loader/pipeline_helpers/build_pipeline';
 import 'ui/capabilities/route_setup';
 
-import { setup as data } from '../../../../../core_plugins/data/public/legacy';
+import { extractTimeFilter, changeTimeFilter } from '../../../../data/public';
+import { start as data } from '../../../../data/public/legacy';
+import { npStart } from 'ui/new_platform';
 
 const { savedQueryService } = data.search.services;
 
@@ -120,44 +121,37 @@ uiRoutes
     resolve: {
       ip: function (Promise, indexPatterns, config, Private) {
         const State = Private(StateProvider);
-        const savedObjectsClient = Private(SavedObjectsClientProvider);
+        return indexPatterns.getCache().then((savedObjects)=> {
+          /**
+           *  In making the indexPattern modifiable it was placed in appState. Unfortunately,
+           *  the load order of AppState conflicts with the load order of many other things
+           *  so in order to get the name of the index we should use, and to switch to the
+           *  default if necessary, we parse the appState with a temporary State object and
+           *  then destroy it immediatly after we're done
+           *
+           *  @type {State}
+           */
+          const state = new State('_a', {});
 
-        return savedObjectsClient.find({
-          type: 'index-pattern',
-          fields: ['title'],
-          perPage: 10000
-        })
-          .then(({ savedObjects }) => {
-            /**
-             *  In making the indexPattern modifiable it was placed in appState. Unfortunately,
-             *  the load order of AppState conflicts with the load order of many other things
-             *  so in order to get the name of the index we should use, and to switch to the
-             *  default if necessary, we parse the appState with a temporary State object and
-             *  then destroy it immediatly after we're done
-             *
-             *  @type {State}
-             */
-            const state = new State('_a', {});
+          const specified = !!state.index;
+          const exists = _.findIndex(savedObjects, o => o.id === state.index) > -1;
+          const id = exists ? state.index : config.get('defaultIndex');
+          state.destroy();
 
-            const specified = !!state.index;
-            const exists = _.findIndex(savedObjects, o => o.id === state.index) > -1;
-            const id = exists ? state.index : config.get('defaultIndex');
-            state.destroy();
-
-            return Promise.props({
-              list: savedObjects,
-              loaded: indexPatterns.get(id),
-              stateVal: state.index,
-              stateValFound: specified && exists
-            });
+          return Promise.props({
+            list: savedObjects,
+            loaded: indexPatterns.get(id),
+            stateVal: state.index,
+            stateValFound: specified && exists
           });
+        });
       },
       savedSearch: function (redirectWhenMissing, savedSearches, $route) {
         const savedSearchId = $route.current.params.id;
         return savedSearches.get(savedSearchId)
           .then((savedSearch) => {
             if (savedSearchId) {
-              recentlyAccessed.add(
+              npStart.core.chrome.recentlyAccessed.add(
                 savedSearch.getFullPath(),
                 savedSearch.title,
                 savedSearchId);
@@ -195,8 +189,6 @@ function discoverController(
   localStorage,
   uiCapabilities
 ) {
-  const visualizeLoader = Private(VisualizeLoaderProvider);
-  let visualizeHandler;
   const Vis = Private(VisProvider);
   const responseHandler = vislibSeriesResponseHandlerProvider().handler;
   const getUnhashableStates = Private(getUnhashableStatesProvider);
@@ -213,6 +205,13 @@ function discoverController(
 
   timefilter.disableTimeRangeSelector();
   timefilter.disableAutoRefreshSelector();
+  $scope.timefilterUpdateHandler = (ranges) => {
+    timefilter.setTime({
+      from: moment(ranges.from).toISOString(),
+      to: moment(ranges.to).toISOString(),
+      mode: 'absolute',
+    });
+  };
 
   $scope.getDocLink = getDocLink;
   $scope.intervalOptions = intervalOptions;
@@ -220,7 +219,6 @@ function discoverController(
   $scope.minimumVisibleRows = 50;
   $scope.fetchStatus = fetchStatuses.UNINITIALIZED;
   $scope.refreshInterval = timefilter.getRefreshInterval();
-  $scope.savedQuery = $route.current.locals.savedQuery;
   $scope.showSaveQuery = uiCapabilities.discover.saveQuery;
 
   $scope.$watch(() => uiCapabilities.discover.saveQuery, (newCapability) => {
@@ -274,12 +272,12 @@ function discoverController(
             isTitleDuplicateConfirmed,
             onTitleDuplicate,
           };
-          return saveDataSource(saveOptions).then(({ id, error }) => {
+          return saveDataSource(saveOptions).then((response) => {
             // If the save wasn't successful, put the original values back.
-            if (!id || error) {
+            if (!response.id || response.error) {
               savedSearch.title = currentTitle;
             }
-            return { id, error };
+            return response;
           });
         };
 
@@ -424,7 +422,10 @@ function discoverController(
   };
 
   $scope.applyFilters = filters => {
-    queryFilter.addFiltersAndChangeTimeFilter(filters);
+    const { timeRangeFilter, restOfFilters } = extractTimeFilter($scope.indexPattern.timeFieldName, filters);
+    queryFilter.addFilters(restOfFilters);
+    if (timeRangeFilter) changeTimeFilter(timefilter, timeRangeFilter);
+
     $scope.state.$newFilters = [];
   };
 
@@ -475,7 +476,7 @@ function discoverController(
 
     const { searchFields, selectFields } = await getSharingDataFields();
     searchSource.setField('fields', searchFields);
-    searchSource.setField('sort', getSort($state.sort, $scope.indexPattern));
+    searchSource.setField('sort', getSortForSearchSource($state.sort, $scope.indexPattern));
     searchSource.setField('highlight', null);
     searchSource.setField('highlightAll', null);
     searchSource.setField('aggs', null);
@@ -546,6 +547,11 @@ function discoverController(
   };
 
   const shouldSearchOnPageLoad = () => {
+    // If a saved query is referenced in the app state, omit the initial load because the saved query will
+    // be fetched separately and trigger a reload
+    if ($scope.state.savedQuery) {
+      return false;
+    }
     // A saved search is created on every page load, so we check the ID to see if we're loading a
     // previously saved search or if it is just transient
     return config.get('discover:searchOnPageLoad')
@@ -620,7 +626,7 @@ function discoverController(
         // no timefield, no vis, nothing to update
           if (!$scope.opts.timefield) return;
 
-          const buckets = $scope.vis.getAggConfig().bySchemaGroup.buckets;
+          const buckets = $scope.vis.getAggConfig().bySchemaGroup('buckets');
 
           if (buckets && buckets.length === 1) {
             $scope.bucketInterval = buckets[0].buckets.getInterval();
@@ -793,15 +799,7 @@ function discoverController(
         .resolve(buildVislibDimensions($scope.vis, { timeRange: $scope.timeRange, searchSource: $scope.searchSource }))
         .then(resp => responseHandler(tabifiedData, resp))
         .then(resp => {
-          visualizeHandler.render({
-            as: 'visualization',
-            value: {
-              visType: $scope.vis.type.name,
-              visData: resp,
-              visConfig: $scope.vis.params,
-              params: {},
-            }
-          });
+          $scope.histogramData = resp;
         });
     }
 
@@ -883,9 +881,10 @@ function discoverController(
   };
 
   $scope.updateDataSource = Promise.method(function updateDataSource() {
-    $scope.searchSource
+    const { indexPattern, searchSource } = $scope;
+    searchSource
       .setField('size', $scope.opts.sampleSize)
-      .setField('sort', getSort($state.sort, $scope.indexPattern))
+      .setField('sort', getSortForSearchSource($state.sort, indexPattern))
       .setField('query', !$state.query ? null : $state.query)
       .setField('filter', queryFilter.getFilters());
   });
@@ -951,6 +950,8 @@ function discoverController(
 
   const updateStateFromSavedQuery = (savedQuery) => {
     $state.query = savedQuery.attributes.query;
+    $state.save();
+
     queryFilter.setFilters(savedQuery.attributes.filters || []);
 
     if (savedQuery.attributes.timefilter) {
@@ -966,15 +967,14 @@ function discoverController(
     $scope.fetch();
   };
 
-  $scope.$watch('savedQuery', (newSavedQuery, oldSavedQuery) => {
+  $scope.$watch('savedQuery', (newSavedQuery) => {
     if (!newSavedQuery) return;
 
     $state.savedQuery = newSavedQuery.id;
     $state.save();
 
-    if (newSavedQuery.id === (oldSavedQuery && oldSavedQuery.id)) {
-      updateStateFromSavedQuery(newSavedQuery);
-    }
+    updateStateFromSavedQuery(newSavedQuery);
+
   });
 
   $scope.$watch('state.savedQuery', newSavedQueryId => {
@@ -983,12 +983,14 @@ function discoverController(
       return;
     }
 
-    savedQueryService.getSavedQuery(newSavedQueryId).then((savedQuery) => {
-      $scope.$evalAsync(() => {
-        $scope.savedQuery = savedQuery;
-        updateStateFromSavedQuery(savedQuery);
+    if (!$scope.savedQuery || newSavedQueryId !== $scope.savedQuery.id) {
+      savedQueryService.getSavedQuery(newSavedQueryId).then((savedQuery) => {
+        $scope.$evalAsync(() => {
+          $scope.savedQuery = savedQuery;
+          updateStateFromSavedQuery(savedQuery);
+        });
       });
-    });
+    }
   });
 
   async function setupVisualization() {
@@ -1046,13 +1048,6 @@ function discoverController(
     $scope.searchSource.setField('aggs', function () {
       return $scope.vis.getAggConfig().toDsl();
     });
-
-    $timeout(async () => {
-      const visEl = $element.find('#discoverHistogram')[0];
-      visualizeHandler = await visualizeLoader.embedVisualizationWithSavedObject(visEl, visSavedObject, {
-        autoFetch: false,
-      });
-    });
   }
 
   function resolveIndexPatternLoading() {
