@@ -24,7 +24,17 @@ var _doc_viewer = require("./doc_viewer");
  */
 // @ts-ignore
 _modules.uiModules.get('apps/discover').directive('docViewer', function (reactDirective) {
-  return reactDirective(_doc_viewer.DocViewer, undefined, {
+  return reactDirective(_doc_viewer.DocViewer, ['hit', ['indexPattern', {
+    watchDepth: 'reference'
+  }], ['filter', {
+    watchDepth: 'reference'
+  }], ['columns', {
+    watchDepth: 'collection'
+  }], ['onAddColumn', {
+    watchDepth: 'reference'
+  }], ['onRemoveColumn', {
+    watchDepth: 'reference'
+  }]], {
     restrict: 'E',
     scope: {
       hit: '=',
