@@ -27,8 +27,7 @@ import { uiModules } from 'ui/modules';
 // import the uiExports that we want to "use"
 import 'uiExports/home';
 import 'uiExports/visTypes';
-import 'uiExports/visResponseHandlers';
-import 'uiExports/visRequestHandlers';
+
 import 'uiExports/visEditorTypes';
 import 'uiExports/visualize';
 import 'uiExports/savedObjectTypes';
@@ -44,7 +43,6 @@ import 'uiExports/embeddableFactories';
 import 'uiExports/embeddableActions';
 import 'uiExports/inspectorViews';
 import 'uiExports/search';
-import 'uiExports/autocompleteProviders';
 import 'uiExports/shareContextMenuExtensions';
 
 import 'ui/autoload/all';
