@@ -115,7 +115,7 @@ uiRoutes
 
       if (this.mode === 'edit') {
         const fieldName = $route.current.params.fieldName;
-        this.field = this.indexPattern.fields.byName[fieldName];
+        this.field = this.indexPattern.fields.getByName(fieldName);
 
         if (!this.field) {
           const message = i18n.translate('kbn.management.editIndexPattern.scripted.noFieldLabel',
