@@ -39,8 +39,9 @@ import {
   EuiCallOut,
 } from '@elastic/eui';
 
+import { npStart } from 'ui/new_platform';
+
 export const EMPTY_FILTER = '';
-const PAGE_SIZE_OPTIONS = [10, 20, 50];
 
 // saved object client does not support sorting by title because title is only mapped as analyzed
 // the legacy implementation got around this by pulling `listingLimit` items and doing client side sorting
@@ -52,6 +53,12 @@ class TableListViewUi extends React.Component {
   constructor(props) {
     super(props);
 
+    const initialPageSize = npStart.core.uiSettings.get('savedObjects:perPage');
+    this.pagination = {
+      initialPageIndex: 0,
+      initialPageSize,
+      pageSizeOptions: _.uniq([10, 20, 50, initialPageSize]).sort(),
+    };
     this.state = {
       items: [],
       totalItems: 0,
@@ -62,8 +69,6 @@ class TableListViewUi extends React.Component {
       showLimitError: false,
       filter: this.props.initialFilter,
       selectedIds: [],
-      page: 0,
-      perPage: 20,
     };
 
   }
@@ -184,7 +189,7 @@ class TableListViewUi extends React.Component {
           title={
             <FormattedMessage
               id="kbn.table_list_view.listing.deleteSelectedConfirmModal.title"
-              defaultMessage="Delete {itemCount} selected {entityName}?"
+              defaultMessage="Delete {itemCount} {entityName}?"
               values={{
                 itemCount: this.state.selectedIds.length,
                 entityName: (this.state.selectedIds.length === 1) ? this.props.entityName : this.props.entityNamePlural
@@ -309,13 +314,6 @@ class TableListViewUi extends React.Component {
   }
 
   renderTable() {
-    const pagination = {
-      pageIndex: this.state.page,
-      pageSize: this.state.perPage,
-      totalItemCount: this.state.items.length,
-      pageSizeOptions: PAGE_SIZE_OPTIONS,
-    };
-
     const selection = this.props.deleteItems ? {
       onSelectionChange: (selection) => {
         this.setState({
@@ -368,7 +366,7 @@ class TableListViewUi extends React.Component {
         itemId="id"
         items={this.state.items}
         columns={columns}
-        pagination={pagination}
+        pagination={this.pagination}
         loading={this.state.isFetchingItems}
         message={noItemsMessage}
         selection={selection}
@@ -400,7 +398,7 @@ class TableListViewUi extends React.Component {
           >
             <FormattedMessage
               id="kbn.table_list_view.listing.createNewItemButtonLabel"
-              defaultMessage="Create new {entityName}"
+              defaultMessage="Create {entityName}"
               values={{ entityName: this.props.entityName }}
             />
           </EuiButton>
