@@ -18,11 +18,10 @@
  */
 
 import './_saved_vis';
-import { VisTypesRegistryProvider } from 'ui/registry/vis_types';
 import { uiModules } from 'ui/modules';
 import { SavedObjectLoader, SavedObjectsClientProvider } from 'ui/saved_objects';
 import { savedObjectManagementRegistry } from '../../management/saved_object_registry';
-import { visualizations } from 'plugins/visualizations';
+import { start as visualizations } from '../../../../visualizations/public/np_ready/public/legacy';
 import { createVisualizeEditUrl } from '../visualize_constants';
 import { findListItems } from './find_list_items';
 
@@ -32,13 +31,18 @@ const app = uiModules.get('app/visualize');
 // edited by the object editor.
 savedObjectManagementRegistry.register({
   service: 'savedVisualizations',
-  title: 'visualizations'
+  title: 'visualizations',
 });
 
 app.service('savedVisualizations', function (SavedVis, Private, kbnUrl, chrome) {
-  const visTypes = Private(VisTypesRegistryProvider);
+  const visTypes = visualizations.types;
   const savedObjectClient = Private(SavedObjectsClientProvider);
-  const saveVisualizationLoader = new SavedObjectLoader(SavedVis, kbnUrl, chrome, savedObjectClient);
+  const saveVisualizationLoader = new SavedObjectLoader(
+    SavedVis,
+    kbnUrl,
+    chrome,
+    savedObjectClient
+  );
 
   saveVisualizationLoader.mapHitSource = function (source, id) {
     source.id = id;
@@ -46,21 +50,23 @@ app.service('savedVisualizations', function (SavedVis, Private, kbnUrl, chrome)
 
     let typeName = source.typeName;
     if (source.visState) {
-      try { typeName = JSON.parse(source.visState).type; }
-      catch (e) { /* missing typename handled below */ } // eslint-disable-line no-empty
+      try {
+        typeName = JSON.parse(source.visState).type;
+      } catch (e) {
+        /* missing typename handled below */
+      } // eslint-disable-line no-empty
     }
 
-    if (!typeName || !visTypes.byName[typeName]) {
+    if (!typeName || !visTypes.get(typeName)) {
       source.error = 'Unknown visualization type';
       return source;
     }
 
-    source.type = visTypes.byName[typeName];
+    source.type = visTypes.get(typeName);
     source.savedObjectType = 'visualization';
     source.icon = source.type.icon;
     source.image = source.type.image;
     source.typeTitle = source.type.title;
-    source.isExperimental = source.type.shouldMarkAsExperimentalInUI();
     source.editUrl = `#${createVisualizeEditUrl(id)}`;
 
     return source;
@@ -78,7 +84,7 @@ app.service('savedVisualizations', function (SavedVis, Private, kbnUrl, chrome)
       size,
       mapSavedObjectApiHits: this.mapSavedObjectApiHits.bind(this),
       savedObjectsClient: this.savedObjectsClient,
-      visTypes: visualizations.types.visTypeAliasRegistry.get(),
+      visTypes: visualizations.types.getAliases(),
     });
   };
 
