@@ -57,9 +57,11 @@ const getAggResultBuckets = (aggConfigs, response, aggWithOtherBucket, key) => {
       for (let aggId = 0; aggId < responseAggs.length; aggId++) {
         const agg = responseAggs[aggId];
         const aggKey = _.keys(responseAgg)[aggId];
-        const aggConfig = _.find(aggConfigs, agg => agg.id === aggKey);
+        const aggConfig = _.find(aggConfigs.aggs, agg => agg.id === aggKey);
         const bucket = _.find(agg.buckets, (bucket, bucketObjKey) => {
-          const bucketKey = aggConfig.getKey(bucket, Number.isInteger(bucketObjKey) ? null : bucketObjKey).toString();
+          const bucketKey = aggConfig
+            .getKey(bucket, Number.isInteger(bucketObjKey) ? null : bucketObjKey)
+            .toString();
           return bucketKey === keyParts[i];
         });
         if (bucket) {
@@ -93,7 +95,7 @@ const getAggConfigResultMissingBuckets = (responseAggs, aggId) => {
       _.each(agg.buckets, bucket => {
         resultBuckets = [
           ...resultBuckets,
-          ...getAggConfigResultMissingBuckets(bucket, aggId, missingKey)
+          ...getAggConfigResultMissingBuckets(bucket, aggId, missingKey),
         ];
       });
     }
@@ -109,30 +111,30 @@ const getAggConfigResultMissingBuckets = (responseAggs, aggId) => {
  * @param otherAgg: AggConfig of the aggregation with other bucket
  */
 const getOtherAggTerms = (requestAgg, key, otherAgg) => {
-  return requestAgg['other-filter'].filters.filters[key].bool.must_not.filter(filter =>
-    filter.match_phrase && filter.match_phrase[otherAgg.params.field.name]
-  ).map(filter =>
-    filter.match_phrase[otherAgg.params.field.name].query
-  );
+  return requestAgg['other-filter'].filters.filters[key].bool.must_not
+    .filter(filter => filter.match_phrase && filter.match_phrase[otherAgg.params.field.name])
+    .map(filter => filter.match_phrase[otherAgg.params.field.name].query);
 };
 
-
 export const buildOtherBucketAgg = (aggConfigs, aggWithOtherBucket, response) => {
-  const bucketAggs = aggConfigs.filter(agg => agg.type.type === AggGroupNames.Buckets);
+  const bucketAggs = aggConfigs.aggs.filter(agg => agg.type.type === AggGroupNames.Buckets);
   const index = bucketAggs.findIndex(agg => agg.id === aggWithOtherBucket.id);
   const aggs = aggConfigs.toDsl();
   const indexPattern = aggWithOtherBucket.params.field.indexPattern;
 
   // create filters aggregation
-  const filterAgg = aggConfigs.createAggConfig({
-    type: 'filters',
-    id: 'other',
-    params: {
-      filters: [],
+  const filterAgg = aggConfigs.createAggConfig(
+    {
+      type: 'filters',
+      id: 'other',
+      params: {
+        filters: [],
+      },
     },
-  }, {
-    addToAggConfigs: false,
-  });
+    {
+      addToAggConfigs: false,
+    }
+  );
 
   // nest all the child aggregations of aggWithOtherBucket
   const resultAgg = {
@@ -156,16 +158,33 @@ export const buildOtherBucketAgg = (aggConfigs, aggWithOtherBucket, response) =>
     const currentAgg = bucketAggs[aggIndex];
     if (aggIndex < index) {
       _.each(agg.buckets, (bucket, bucketObjKey) => {
-        const bucketKey = currentAgg.getKey(bucket, Number.isInteger(bucketObjKey) ? null : bucketObjKey);
+        const bucketKey = currentAgg.getKey(
+          bucket,
+          Number.isInteger(bucketObjKey) ? null : bucketObjKey
+        );
         const filter = _.cloneDeep(bucket.filters) || currentAgg.createFilter(bucketKey);
         const newFilters = _.flatten([...filters, filter]);
-        walkBucketTree(newAggIndex, bucket, newAgg.id, newFilters, `${key}-${bucketKey.toString()}`);
+        walkBucketTree(
+          newAggIndex,
+          bucket,
+          newAgg.id,
+          newFilters,
+          `${key}-${bucketKey.toString()}`
+        );
       });
       return;
     }
 
-    if (!aggWithOtherBucket.params.missingBucket || agg.buckets.some(bucket => bucket.key === '__missing__')) {
-      filters.push(buildExistsFilter(aggWithOtherBucket.params.field, aggWithOtherBucket.params.field.indexPattern));
+    if (
+      !aggWithOtherBucket.params.missingBucket ||
+      agg.buckets.some(bucket => bucket.key === '__missing__')
+    ) {
+      filters.push(
+        buildExistsFilter(
+          aggWithOtherBucket.params.field,
+          aggWithOtherBucket.params.field.indexPattern
+        )
+      );
     }
 
     // create not filters for all the buckets
@@ -177,7 +196,7 @@ export const buildOtherBucketAgg = (aggConfigs, aggWithOtherBucket, response) =>
     });
 
     resultAgg.filters.filters[key] = {
-      bool: buildQueryFromFilters(filters, indexPattern)
+      bool: buildQueryFromFilters(filters, indexPattern),
     };
   };
   walkBucketTree(0, response.aggregations, bucketAggs[0].id, [], '');
@@ -189,26 +208,43 @@ export const buildOtherBucketAgg = (aggConfigs, aggWithOtherBucket, response) =>
 
   return () => {
     return {
-      'other-filter': resultAgg
+      'other-filter': resultAgg,
     };
   };
 };
 
-export const mergeOtherBucketAggResponse = (aggsConfig, response, otherResponse, otherAgg, requestAgg) => {
+export const mergeOtherBucketAggResponse = (
+  aggsConfig,
+  response,
+  otherResponse,
+  otherAgg,
+  requestAgg
+) => {
   const updatedResponse = _.cloneDeep(response);
   _.each(otherResponse.aggregations['other-filter'].buckets, (bucket, key) => {
     if (!bucket.doc_count) return;
     const bucketKey = key.replace(/^-/, '');
-    const aggResultBuckets = getAggResultBuckets(aggsConfig, updatedResponse.aggregations, otherAgg, bucketKey);
+    const aggResultBuckets = getAggResultBuckets(
+      aggsConfig,
+      updatedResponse.aggregations,
+      otherAgg,
+      bucketKey
+    );
     const requestFilterTerms = getOtherAggTerms(requestAgg, key, otherAgg);
 
-    const phraseFilter = buildPhrasesFilter(otherAgg.params.field, requestFilterTerms, otherAgg.params.field.indexPattern);
+    const phraseFilter = buildPhrasesFilter(
+      otherAgg.params.field,
+      requestFilterTerms,
+      otherAgg.params.field.indexPattern
+    );
     phraseFilter.meta.negate = true;
-    bucket.filters = [ phraseFilter ];
+    bucket.filters = [phraseFilter];
     bucket.key = '__other__';
 
     if (aggResultBuckets.some(bucket => bucket.key === '__missing__')) {
-      bucket.filters.push(buildExistsFilter(otherAgg.params.field, otherAgg.params.field.indexPattern));
+      bucket.filters.push(
+        buildExistsFilter(otherAgg.params.field, otherAgg.params.field.indexPattern)
+      );
     }
     aggResultBuckets.push(bucket);
   });
