@@ -72,12 +72,16 @@ export function kbnChromeProvider(chrome, internals) {
           // Non-scope based code (e.g., React)
 
           // Banners
-          ReactDOM.render(
-            <I18nContext>
-              {npStart.core.overlays.banners.getComponent()}
-            </I18nContext>,
-            document.getElementById('globalBannerList')
-          );
+          const bannerListContainer = document.getElementById('globalBannerList');
+          if (bannerListContainer) {
+            // This gets rendered manually by the legacy platform because this component must be inside the .app-wrapper
+            ReactDOM.render(
+              <I18nContext>
+                {npStart.core.overlays.banners.getComponent()}
+              </I18nContext>,
+              bannerListContainer
+            );
+          }
 
           return chrome;
         }
