@@ -80,7 +80,8 @@ import { SearchRequestProvider } from '../fetch/request';
 import { searchRequestQueue } from '../search_request_queue';
 import { FetchSoonProvider } from '../fetch';
 import { FieldWildcardProvider } from '../../field_wildcard';
-import { getHighlightRequest } from '../../../../core_plugins/kibana/common/highlight';
+import { getHighlightRequest } from '../../../../../plugins/data/common/field_formats';
+import { filterDocvalueFields } from './filter_docvalue_fields';
 
 const FIELDS = [
   'type',
@@ -551,12 +552,13 @@ export function SearchSourceProvider(Promise, Private, config) {
           flatData.body = flatData.body || {};
 
           const computedFields = flatData.index.getComputedFields();
+
           flatData.body.stored_fields = computedFields.storedFields;
           flatData.body.script_fields = flatData.body.script_fields || {};
-          flatData.body.docvalue_fields = flatData.body.docvalue_fields || [];
-
           _.extend(flatData.body.script_fields, computedFields.scriptFields);
-          flatData.body.docvalue_fields = _.union(flatData.body.docvalue_fields, computedFields.docvalueFields);
+
+          const defaultDocValueFields = computedFields.docvalueFields ? computedFields.docvalueFields : [];
+          flatData.body.docvalue_fields = flatData.body.docvalue_fields || defaultDocValueFields;
 
           if (flatData.body._source) {
             // exclude source fields for this index pattern specified by the user
@@ -570,7 +572,7 @@ export function SearchSourceProvider(Promise, Private, config) {
           const fields = flatData.fields;
           if (fields) {
             // filter out the docvalue_fields, and script_fields to only include those that we are concerned with
-            flatData.body.docvalue_fields = _.intersection(flatData.body.docvalue_fields, fields);
+            flatData.body.docvalue_fields = filterDocvalueFields(flatData.body.docvalue_fields, fields);
             flatData.body.script_fields = _.pick(flatData.body.script_fields, fields);
 
             // request the remaining fields from both stored_fields and _source
