@@ -40,6 +40,7 @@ uiModules
       'groupName',
       'formIsTouched',
       'lastParentPipelineAggTitle',
+      'currentTab',
     ])
   )
   .directive('visEditorAggGroup', function () {
@@ -50,6 +51,7 @@ uiModules
       template: function () {
         return `<vis-editor-agg-group-wrapper	
             ng-if="setValidity"	
+            current-tab="sidebar.section"
             form-is-touched="formIsTouched"
             group-name="groupName"
             last-parent-pipeline-agg-title="lastParentPipelineAggTitle"
