@@ -19,7 +19,6 @@
 
 import _ from 'lodash';
 import { IndexedArray } from '../../../indexed_array';
-import { AggParams } from '../../../agg_types/agg_params';
 import { RowsOrColumnsControl } from './controls/rows_or_columns';
 import { RadiusRatioOptionControl } from './controls/radius_ratio_option';
 import { AggGroupNames } from './agg_groups';
@@ -53,9 +52,6 @@ class Schemas {
           params: [],
         });
 
-        // convert the params into a params registry
-        schema.params = new AggParams(schema.params);
-
         return schema;
       })
       .tap((schemas) => {
