@@ -19,7 +19,6 @@
 
 import { buildHierarchicalData } from '../../agg_response/hierarchical/build_hierarchical_data';
 import { buildPointSeriesData } from '../../agg_response/point_series/point_series';
-import { VisResponseHandlersRegistryProvider } from '../../registry/vis_response_handlers';
 import { legacyResponseHandlerProvider } from './legacy';
 
 const tableResponseHandler = legacyResponseHandlerProvider().handler;
@@ -92,8 +91,3 @@ export const vislibSlicesResponseHandlerProvider = function () {
   };
 };
 
-
-
-VisResponseHandlersRegistryProvider.register(vislibSeriesResponseHandlerProvider);
-VisResponseHandlersRegistryProvider.register(vislibSlicesResponseHandlerProvider);
-
