@@ -20,7 +20,7 @@
 import d3 from 'd3';
 import _ from 'lodash';
 import MarkdownIt from 'markdown-it';
-import { NoResults } from '../../errors';
+import { NoResults } from '../errors';
 import { Binder } from '../../binder';
 import { Layout } from './layout/layout';
 import { ChartTitle } from './chart_title';
@@ -28,7 +28,7 @@ import { Alerts } from './alerts';
 import { Axis } from './axis/axis';
 import { ChartGrid as Grid } from './chart_grid';
 import { visTypes as chartTypes } from '../visualizations/vis_types';
-import { dispatchRenderComplete } from '../../render_complete';
+import { dispatchRenderComplete } from '../../../../../plugins/kibana_utils/public';
 
 const markdownIt = new MarkdownIt({
   html: false,
